@@ -3,14 +3,14 @@ import { Match } from '../match';
 export interface Recogniser {
   match(input: Context): Match | null;
   name(input?: Context): string;
-  language?(): string;
+  language?(): string | undefined;
 }
 
 export interface Context {
-  fByteStats: number[];
-  fC1Bytes: boolean;
-  fRawInput: Uint8Array;
-  fRawLength: number;
-  fInputBytes: Uint8Array;
-  fInputLen: number;
+  byteStats: number[];
+  c1Bytes: boolean;
+  rawInput: Uint8Array;
+  rawLen: number;
+  inputBytes: Uint8Array;
+  inputLen: number;
 }
