@@ -58,9 +58,9 @@ class NGramParser {
   }
 
   nextByte(det: Context) {
-    if (this.byteIndex >= det.fInputLen) return -1;
+    if (this.byteIndex >= det.inputLen) return -1;
 
-    return det.fInputBytes[this.byteIndex++] & 0xff;
+    return det.inputBytes[this.byteIndex++] & 0xff;
   }
 
   parse(det: Context, spaceCh: number) {
@@ -110,6 +110,8 @@ const isFlatNgrams = (val: NGramsPlusLang[] | number[]): val is number[] =>
 class sbcs implements Recogniser {
   spaceChar = 0x20;
 
+  private nGramLang?: string = undefined;
+
   ngrams(): NGramsPlusLang[] | number[] {
     return [];
   }
@@ -122,7 +124,16 @@ class sbcs implements Recogniser {
     return 'sbcs';
   }
 
+  language(): string | undefined {
+    return this.nGramLang;
+  }
+
   match(det: Context): Match | null {
+    // This feels a bit dirty. Simpler alternative would be
+    // splitting classes ISO_8859_1 etc into language-specific ones
+    // with hardcoded languages like ISO_8859_9.
+    this.nGramLang = undefined;
+
     const ngrams = this.ngrams();
 
     if (isFlatNgrams(ngrams)) {
@@ -131,24 +142,20 @@ class sbcs implements Recogniser {
       return confidence <= 0 ? null : match(det, this, confidence);
     }
 
-    let bestConfidenceSoFar = -1;
-    let lang;
+    let bestConfidence = -1;
 
     for (let i = ngrams.length - 1; i >= 0; i--) {
       const ngl = ngrams[i];
 
       const parser = new NGramParser(ngl.fNGrams, this.byteMap());
       const confidence = parser.parse(det, this.spaceChar);
-      if (confidence > bestConfidenceSoFar) {
-        bestConfidenceSoFar = confidence;
-        lang = ngl.fLang;
+      if (confidence > bestConfidence) {
+        bestConfidence = confidence;
+        this.nGramLang = ngl.fLang;
       }
     }
 
-    const name = this.name(det);
-    return bestConfidenceSoFar <= 0
-      ? null
-      : match(det, this, bestConfidenceSoFar, name, lang);
+    return bestConfidence <= 0 ? null : match(det, this, bestConfidence);
   }
 }
 
@@ -1080,7 +1087,7 @@ export class ISO_8859_1 extends sbcs {
   }
 
   name(input: Context): string {
-    return input && input.fC1Bytes ? 'windows-1252' : 'ISO-8859-1';
+    return input && input.c1Bytes ? 'windows-1252' : 'ISO-8859-1';
   }
 }
 
@@ -1616,7 +1623,7 @@ export class ISO_8859_2 extends sbcs {
   }
 
   name(det: Context): string {
-    return det && det.fC1Bytes ? 'windows-1250' : 'ISO-8859-2';
+    return det && det.c1Bytes ? 'windows-1250' : 'ISO-8859-2';
   }
 }
 
@@ -2632,7 +2639,7 @@ export class ISO_8859_7 extends sbcs {
   }
 
   name(det: Context): string {
-    return det && det.fC1Bytes ? 'windows-1253' : 'ISO-8859-7';
+    return det && det.c1Bytes ? 'windows-1253' : 'ISO-8859-7';
   }
 
   language() {
@@ -3040,7 +3047,7 @@ export class ISO_8859_8 extends sbcs {
   }
 
   name(det: Context): string {
-    return det && det.fC1Bytes ? 'windows-1255' : 'ISO-8859-8';
+    return det && det.c1Bytes ? 'windows-1255' : 'ISO-8859-8';
   }
 
   language() {
@@ -3380,7 +3387,7 @@ export class ISO_8859_9 extends sbcs {
   }
 
   name(det: Context): string {
-    return det && det.fC1Bytes ? 'windows-1254' : 'ISO-8859-9';
+    return det && det.c1Bytes ? 'windows-1254' : 'ISO-8859-9';
   }
 
   language() {
@@ -4425,7 +4432,7 @@ module.exports.ISO_8859_7 = function() {
   this.name = function(det) {
     if (typeof det == 'undefined')
       return 'ISO-8859-7';
-    return det.fC1Bytes ? 'windows-1253' : 'ISO-8859-7';
+    return det.c1Bytes ? 'windows-1253' : 'ISO-8859-7';
   };
 
   language() {
